@@ -5,10 +5,10 @@ class ModeAccueil(EnhancedEnum):
     A_DISTANCE = (
         "a-distance",
         "À distance",
-        None,
+        "Le service est proposé à distance, par téléphone ou internet.",
     )
     EN_PRESENTIEL = (
         "en-presentiel",
         "En présentiel",
-        None,
+        "Le service est proposé en présentiel, à l'adresse associée à ce service.",
     )
