@@ -171,6 +171,11 @@ class Thematique(EnhancedEnum):
         "Alimentation",
         None,
     )
+    EQUIPEMENT_ET_ALIMENTATION__AIDE_MENAGERE = (
+        "equipement-et-alimentation--aide-menagere",
+        "Aide ménagère",
+        None,
+    )
     EQUIPEMENT_ET_ALIMENTATION__ELECTROMENAGER = (
         "equipement-et-alimentation--electromenager",
         "Électroménager",
@@ -284,6 +289,11 @@ class Thematique(EnhancedEnum):
         "Adapter son logement",
         None,
     )
+    HANDICAP__AIDE_A_LA_PERSONNE = (
+        "handicap--aide-a-la-personne",
+        "Aide à la personne en situation de handicap ou malade",
+        None,
+    )
     HANDICAP__CONNAISSANCE_DES_DROITS_DES_TRAVAILLEURS = (
         "handicap--connaissance-des-droits-des-travailleurs",
         "Connaissance des droits des travailleurs",
