@@ -1,7 +1,7 @@
 from data_inclusion.schema.base import EnhancedEnum
 
 
-class Typologie(EnhancedEnum):
+class TypologieStructure(EnhancedEnum):
     ACI = (
         "ACI",
         "Structures porteuses d’ateliers et chantiers d’insertion (ACI)",
@@ -248,6 +248,21 @@ class Typologie(EnhancedEnum):
         "Entreprise de l’Économie Sociale et Solidaire",
         None,
     )
+    ETABL_PRI = (
+        "ETABL_PRI",
+        "Établissement privé",
+        None,
+    )
+    ETABL_PUB = (
+        "ETABL_PUB",
+        "Établissement public",
+        None,
+    )
+    ETAT = (
+        "ETAT",
+        "Service de l'État",
+        None,
+    )
     ETTI = (
         "ETTI",
         "Entreprises de travail temporaire d’insertion (ETTI)",
@@ -371,11 +386,6 @@ class Typologie(EnhancedEnum):
         "Point d’Accès au Droit",
         None,
     )
-    PE = (
-        "PE",
-        "Pôle emploi",
-        None,
-    )
     PENSION = (
         "PENSION",
         "Pension de famille / résidence accueil",
